@@ -1,5 +1,3 @@
-
-
 from .idf import filter_idf
 
 
@@ -7,11 +5,15 @@ def jaccard_sigs(i, j, siglist):
     return siglist[i].jaccard(siglist[j])
 
 
-def jaccard_sigs_idf(i, j, siglist, idf, mean_idf_per_cell, ):
-    i_hashes = filter_idf(siglist[i].get_mins(),
-                          idf, mean_idf_per_cell)
-    j_hashes = filter_idf(siglist[j].get_mins(),
-                          idf, mean_idf_per_cell)
+def jaccard_sigs_idf(
+    i,
+    j,
+    siglist,
+    idf,
+    mean_idf_per_cell,
+):
+    i_hashes = filter_idf(siglist[i].get_mins(), idf, mean_idf_per_cell)
+    j_hashes = filter_idf(siglist[j].get_mins(), idf, mean_idf_per_cell)
     return jaccard(i_hashes, j_hashes)
 
 
